type BlobInput = ReadableStream | string | ArrayBuffer | Blob;
type Fetcher = typeof globalThis.fetch;
declare enum HTTPMethod {
    DELETE = "delete",
    GET = "get",
    PUT = "put"
}

interface MakeStoreRequestOptions {
    body?: BlobInput | null;
    headers?: Record<string, string>;
    key: string;
    method: HTTPMethod;
    storeName: string;
}
interface ClientOptions {
    apiURL?: string;
    edgeURL?: string;
    fetch?: Fetcher;
    siteID: string;
    token: string;
}
declare class Client {
    private apiURL?;
    private edgeURL?;
    private fetch?;
    private siteID;
    private token;
    constructor({ apiURL, edgeURL, fetch, siteID, token }: ClientOptions);
    private getFinalRequest;
    makeRequest({ body, headers: extraHeaders, key, method, storeName }: MakeStoreRequestOptions): Promise<Response | null>;
}

interface BaseStoreOptions {
    client: Client;
}
interface DeployStoreOptions extends BaseStoreOptions {
    deployID: string;
}
interface NamedStoreOptions extends BaseStoreOptions {
    name: string;
}
type StoreOptions = DeployStoreOptions | NamedStoreOptions;
interface SetOptions {
    /**
     * Accepts an absolute date as a `Date` object, or a relative date as the
     * number of seconds from the current date.
     */
    expiration?: Date | number;
}
declare class Store {
    private client;
    private name;
    constructor(options: StoreOptions);
    private static getExpirationHeaders;
    delete(key: string): Promise<void>;
    get(key: string): Promise<string>;
    get(key: string, { type }: {
        type: 'arrayBuffer';
    }): Promise<ArrayBuffer>;
    get(key: string, { type }: {
        type: 'blob';
    }): Promise<Blob>;
    get(key: string, { type }: {
        type: 'json';
    }): Promise<any>;
    get(key: string, { type }: {
        type: 'stream';
    }): Promise<ReadableStream>;
    get(key: string, { type }: {
        type: 'text';
    }): Promise<string>;
    set(key: string, data: BlobInput, { expiration }?: SetOptions): Promise<void>;
    setJSON(key: string, data: unknown, { expiration }?: SetOptions): Promise<void>;
}
/**
 * Gets a reference to a deploy-scoped store.
 */
declare const getDeployStore: (options?: Partial<ClientOptions>) => Store;
interface GetStoreOptions extends Partial<ClientOptions> {
    deployID?: string;
    name?: string;
}
/**
 * Gets a reference to a store.
 *
 * @param input Either a string containing the store name or an options object
 */
declare const getStore: {
    (name: string): Store;
    (options: GetStoreOptions): Store;
};

export { getDeployStore, getStore };
